@@ -1,5 +1,6 @@
 package org.rosuda.REngine;
 
+/** represents a pairlist in R */
 public class REXPList extends REXPVector {
 	private RList payload;
 	
@@ -16,6 +17,9 @@ public class REXPList extends REXPVector {
 	public int length() { return payload.size(); }
 
 	public boolean isList() { return true; }
+
+	public boolean isRecursive() { return true; }
+
 	public RList asList() { return payload; }
 	
 	public String toString() {
